==> igniteui-react-charts-16.6.8.tgz: package/ES5/CategoryHighlightLayer_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { AnnotationLayer } from "./AnnotationLayer";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { CategoryHighlightLayerFrame } from "./CategoryHighlightLayerFrame";
import { Type, Base, Number_$type, typeCast, fromEnum, Point_$type, markType, runOn } from "igniteui-react-core/ES5/type";
import { XamDataChart } from "./XamDataChart";
import { CategoryHighlightFrameRect } from "./CategoryHighlightFrameRect";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { Pool$1 } from "igniteui-react-core/ES5/Pool$1";
import { Rectangle } from "igniteui-react-core/ES5/Rectangle";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { isNaN_, truncate } from "igniteui-react-core/ES5/number";
import { AnnotationLayerView } from "./AnnotationLayerView";
import { BrushUtil } from "igniteui-react-core/ES5/BrushUtil";
import { Color } from "igniteui-react-core/ES5/Color";
/**
 * @hidden
 */
var CategoryHighlightLayer = /** @class */ (function (_super) {
    tslib_1.__extends(CategoryHighlightLayer, _super);
    function CategoryHighlightLayer() {
        var _this = _super.call(this) || this;
        var a = new CategoryHighlightLayerFrame();
        var b = new CategoryHighlightLayerFrame();
        var c = new CategoryHighlightLayerFrame();
        var d = _this.ff / 1000;
        _this.lv = a;
        _this.lu = b;
        _this.lw = c;
        _this.ab = CategoryHighlightLayer.$;
        return _this;
    }
    CategoryHighlightLayer.prototype.bf = function () {
        return new CategoryHighlightLayerView(this);
    };
    CategoryHighlightLayer.prototype.im = function (a) {
        _super.prototype.im.call(this, a);
        this.mw = a;
    };
    Object.defineProperty(CategoryHighlightLayer.prototype, "mz", {
        get: function () {
            return this.c(CategoryHighlightLayer.m6);
        },
        set: function (a) {
            this.h(CategoryHighlightLayer.m6, a);
        },
        enumerable: true,
        configurable: true
    });
    CategoryHighlightLayer.prototype.mb = function (a, b) {
        if (this.mv == null || this.mv == a) {
            if (!this.aq.c) {
                this.i6(b);
            }
        }
    };
    CategoryHighlightLayer.prototype.mx = function (a) {
        return a != null && a.cd();
    };
    CategoryHighlightLayer.prototype.me = function (a, b) {
        var e_1, _a;
        _super.prototype.me.call(this, a, b);
        var c = a;
        c.g.clear();
        var d = this.my;
        if (isNaN_(this.ms.x) && isNaN_(this.ms.y)) {
            return;
        }
        if (this.mv != null) {
            if (this.mx(this.mv)) {
                this.m4(this.mv, c, d);
            }
        }
        else {
            if (typeCast(XamDataChart.$, this.bs) !== null) {
                var e = this.bs;
                try {
                    for (var _b = tslib_1.__values(fromEnum(e.axes)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var f = _c.value;
                        if (typeCast(CategoryAxisBase.$, f) !== null && this.mx(f)) {
                            this.m4(f, c, d);
                        }
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
        }
    };
    CategoryHighlightLayer.prototype.m4 = function (a, b, c) {
        if (this.bi == null || this.bi.bs.isEmpty || this.bi.br.isEmpty) {
            return;
        }
        var d = this.ms.x;
        if (a.ce && isNaN_(d)) {
            d = 0;
        }
        d = this.bi.br.left + this.bi.br.width * (d - this.bi.bs.left) / this.bi.bs.width;
        var e = this.ms.y;
        if (!a.ce && isNaN_(e)) {
            e = 0;
        }
        e = this.bi.br.top + this.bi.br.height * (e - this.bi.bs.top) / this.bi.bs.height;
        var f = a.kn({ $type: Point_$type, x: d, y: e }, c, this.mz);
        this.m3(f, b, a);
    };
    CategoryHighlightLayer.prototype.m3 = function (a, b, c) {
        var d = new CategoryHighlightFrameRect();
        d.b = a.left;
        d.e = a.top;
        d.c = a.right;
        d.a = a.bottom;
        d.g = this.mq();
        d.h = this.mr();
        if (d.g == null) {
            d.g = this.mw.b9(c.ib);
        }
        if (d.h == null) {
            d.h = this.mw.b9(c.ib);
        }
        d.d = this.ev;
        d.f = Base.getHashCodeStatic(c);
        if (!a.isEmpty) {
            b.g.addItem(d.f, d);
        }
    };
    CategoryHighlightLayer.prototype.mh = function (a, b) {
        var e_2, _a;
        _super.prototype.mh.call(this, a, b);
        var c = this.mw.b2;
        var d = a;
        var e = 0;
        try {
            for (var _b = tslib_1.__values(fromEnum(d.g.values)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var f = _c.value;
                var g = c.item(e);
                this.m5(f, g);
                e++;
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_2) throw e_2.error; }
        }
        c.count = e;
    };
    CategoryHighlightLayer.prototype.c7 = function () {
        return true;
    };
    CategoryHighlightLayer.prototype.m5 = function (a, b) {
        if (isNaN_(a.b) || isNaN_(a.e) || isNaN_(a.a) || isNaN_(a.c) || isNaN_(a.d)) {
            b._visibility = 1;
            return;
        }
        this.mw.b4(b, a.b, a.e, a.c - a.b, a.a - a.e);
        b._fill = a.g;
        b._stroke = a.h;
        b.ac = a.d;
        if (this.k4 != null) {
            b.ai = this.k4;
        }
        else {
            b.ai = null;
        }
        b.ad = this.k5;
    };
    CategoryHighlightLayer.prototype.is = function (a, b, c, d) {
        _super.prototype.is.call(this, a, b, c, d);
        switch (b) {
            case CategoryHighlightLayer.$$p[0]:
                this.i6(true);
                break;
            case CategoryHighlightLayer.$$p[1]:
                this.i6(true);
                break;
        }
    };
    CategoryHighlightLayer.$t = markType(CategoryHighlightLayer, 'CategoryHighlightLayer', AnnotationLayer.$);
    CategoryHighlightLayer.m6 = DependencyProperty.i("BAndHighlightWidth", Number_$type, CategoryHighlightLayer.$, new PropertyMetadata(2, 10, function (a, b) { return a.raisePropertyChanged("BAndHighlightWidth", b.oldValue, b.newValue); }));
    return CategoryHighlightLayer;
}(AnnotationLayer));
export { CategoryHighlightLayer };
Type.dep(DependencyProperty, PropertyMetadata, CategoryHighlightLayer, 'raisePropertyChanged', ['TargetAxis:mv:m7', [CategoryAxisBase.$, null], 'UseInterpolation:my:m8', [0, false]]);
/**
 * @hidden
 */
var CategoryHighlightLayerView = /** @class */ (function (_super) {
    tslib_1.__extends(CategoryHighlightLayerView, _super);
    function CategoryHighlightLayerView(a) {
        var _this = _super.call(this, a) || this;
        _this.b1 = null;
        _this.b2 = null;
        _this.b3 = null;
        _this.b1 = a;
        _this.b3 = new List$1(Rectangle.$, 0);
        return _this;
    }
    CategoryHighlightLayerView.prototype.ap = function () {
        var _this = this;
        _super.prototype.ap.call(this);
        this.b2 = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.ca);
            $ret.activate = runOn(_this, _this.b5);
            $ret.disactivate = runOn(_this, _this.b7);
            $ret.destroy = runOn(_this, _this.b6);
            return $ret;
        })());
    };
    CategoryHighlightLayerView.prototype.ca = function () {
        var a = new Rectangle();
        a.ab = false;
        this.b3.add(a);
        return a;
    };
    CategoryHighlightLayerView.prototype.b5 = function (a) {
        a._visibility = 0;
    };
    CategoryHighlightLayerView.prototype.b7 = function (a) {
        a._visibility = 1;
    };
    CategoryHighlightLayerView.prototype.b6 = function (a) {
        this.b3.remove(a);
    };
    CategoryHighlightLayerView.prototype.b8 = function (a) {
        if (a == null) {
            return a;
        }
        return BrushUtil.h(a, 0.1);
    };
    CategoryHighlightLayerView.prototype.b9 = function (a) {
        if (a != null) {
            var b = BrushUtil.h(a, 0.3);
            if (b.isGradient) {
                var c = b;
                if (c.gradientStops != null) {
                    for (var d = 0; d < c.gradientStops.length; d++) {
                        var e = c.gradientStops[d];
                        e.color = Color.u(truncate(Math.round((e.color.l) * 0.2)), e.color.o, e.color.n, e.color.m);
                        e.color = e.color;
                    }
                }
            }
            else {
                b.color = Color.u(truncate(Math.round((b.color.l) * 0.2)), b.color.o, b.color.n, b.color.m);
                b.color = b.color;
            }
            return b;
        }
        else {
            return null;
        }
    };
    CategoryHighlightLayerView.prototype.b4 = function (a, b, c, d, e) {
        a._visibility = 0;
        a.n = b;
        a.o = c;
        a.width = d;
        a.height = e;
    };
    CategoryHighlightLayerView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d && !b) {
            for (var c = 0; c < this.b3.count; c++) {
                var d = this.b3._inner[c];
                if (d._visibility == 0) {
                    a.v(d);
                }
            }
        }
    };
    CategoryHighlightLayerView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        for (var b = 0; b < this.b3.count; b++) {
            this.e.a2.exportRectangleData(a, this.b3._inner[b], "cihRect", ["Main", "CategoryItem"]);
        }
    };
    CategoryHighlightLayerView.$t = markType(CategoryHighlightLayerView, 'CategoryHighlightLayerView', AnnotationLayerView.$);
    return CategoryHighlightLayerView;
}(AnnotationLayerView));
export { CategoryHighlightLayerView };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/CategoryHighlightLayer_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { AnnotationLayer } from "./AnnotationLayer";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { CategoryHighlightLayerFrame } from "./CategoryHighlightLayerFrame";
import { Type, Base, Number_$type, typeCast, fromEnum, Point_$type, markType, runOn } from "igniteui-react-core/ES5/type";
import { XamDataChart } from "./XamDataChart";
import { CategoryHighlightFrameRect } from "./CategoryHighlightFrameRect";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { Pool$1 } from "igniteui-react-core/ES5/Pool$1";
import { Rectangle } from "igniteui-react-core/ES5/Rectangle";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { isNaN_, truncate } from "igniteui-react-core/ES5/number";
import { AnnotationLayerView } from "./AnnotationLayerView";
import { BrushUtil } from "igniteui-react-core/ES5/BrushUtil";
import { Color } from "igniteui-react-core/ES5/Color";
/**
 * @hidden
 */
var CategoryHighlightLayer = /** @class */ (function (_super) {
    tslib_1.__extends(CategoryHighlightLayer, _super);
    function CategoryHighlightLayer() {
        var _this = _super.call(this) || this;
        var a = new CategoryHighlightLayerFrame();
        var b = new CategoryHighlightLayerFrame();
        var c = new CategoryHighlightLayerFrame();
        var d = _this.fi / 1000;
        _this.l2 = a;
        _this.l1 = b;
        _this.l3 = c;
        _this.ab = CategoryHighlightLayer.$;
        return _this;
    }
    CategoryHighlightLayer.prototype.bf = function () {
        return new CategoryHighlightLayerView(this);
    };
    CategoryHighlightLayer.prototype.iu = function (a) {
        _super.prototype.iu.call(this, a);
        this.m5 = a;
    };
    Object.defineProperty(CategoryHighlightLayer.prototype, "m8", {
        get: function () {
            return this.c(CategoryHighlightLayer.nf);
        },
        set: function (a) {
            this.h(CategoryHighlightLayer.nf, a);
        },
        enumerable: true,
        configurable: true
    });
    CategoryHighlightLayer.prototype.mk = function (a, b) {
        if (this.m4 == null || this.m4 == a) {
            if (!this.aq.c) {
                this.jd(b);
            }
        }
    };
    CategoryHighlightLayer.prototype.m6 = function (a) {
        return a != null && a.ce();
    };
    CategoryHighlightLayer.prototype.mn = function (a, b) {
        var e_1, _a;
        _super.prototype.mn.call(this, a, b);
        var c = a;
        c.g.clear();
        var d = this.m7;
        if (isNaN_(this.m1.x) && isNaN_(this.m1.y)) {
            return;
        }
        if (this.m4 != null) {
            if (this.m6(this.m4)) {
                this.nd(this.m4, c, d);
            }
        }
        else {
            if (typeCast(XamDataChart.$, this.bs) !== null) {
                var e = this.bs;
                try {
                    for (var _b = tslib_1.__values(fromEnum(e.axes)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var f = _c.value;
                        if (typeCast(CategoryAxisBase.$, f) !== null && this.m6(f)) {
                            this.nd(f, c, d);
                        }
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
        }
    };
    CategoryHighlightLayer.prototype.nd = function (a, b, c) {
        if (this.bi == null || this.bi.bs.isEmpty || this.bi.br.isEmpty) {
            return;
        }
        var d = this.m1.x;
        if (a.cf && isNaN_(d)) {
            d = 0;
        }
        d = this.bi.br.left + this.bi.br.width * (d - this.bi.bs.left) / this.bi.bs.width;
        var e = this.m1.y;
        if (!a.cf && isNaN_(e)) {
            e = 0;
        }
        e = this.bi.br.top + this.bi.br.height * (e - this.bi.bs.top) / this.bi.bs.height;
        var f = a.ku({ $type: Point_$type, x: d, y: e }, c, this.m8);
        this.nc(f, b, a);
    };
    CategoryHighlightLayer.prototype.nc = function (a, b, c) {
        var d = new CategoryHighlightFrameRect();
        d.b = a.left;
        d.e = a.top;
        d.c = a.right;
        d.a = a.bottom;
        d.g = this.mz();
        d.h = this.m0();
        if (d.g == null) {
            d.g = this.m5.b9(c.ii);
        }
        if (d.h == null) {
            d.h = this.m5.b9(c.ii);
        }
        d.d = this.ey;
        d.f = Base.getHashCodeStatic(c);
        if (!a.isEmpty) {
            b.g.addItem(d.f, d);
        }
    };
    CategoryHighlightLayer.prototype.mq = function (a, b) {
        var e_2, _a;
        _super.prototype.mq.call(this, a, b);
        var c = this.m5.b2;
        var d = a;
        var e = 0;
        try {
            for (var _b = tslib_1.__values(fromEnum(d.g.values)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var f = _c.value;
                var g = c.item(e);
                this.ne(f, g);
                e++;
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_2) throw e_2.error; }
        }
        c.count = e;
    };
    CategoryHighlightLayer.prototype.c8 = function () {
        return true;
    };
    CategoryHighlightLayer.prototype.ne = function (a, b) {
        if (isNaN_(a.b) || isNaN_(a.e) || isNaN_(a.a) || isNaN_(a.c) || isNaN_(a.d)) {
            b._visibility = 1;
            return;
        }
        this.m5.b4(b, a.b, a.e, a.c - a.b, a.a - a.e);
        b._fill = a.g;
        b._stroke = a.h;
        b.ac = a.d;
        if (this.lb != null) {
            b.ai = this.lb;
        }
        else {
            b.ai = null;
        }
        b.ad = this.lc;
    };
    CategoryHighlightLayer.prototype.iz = function (a, b, c, d) {
        _super.prototype.iz.call(this, a, b, c, d);
        switch (b) {
            case CategoryHighlightLayer.$$p[0]:
                this.jd(true);
                break;
            case CategoryHighlightLayer.$$p[1]:
                this.jd(true);
                break;
        }
    };
    CategoryHighlightLayer.$t = markType(CategoryHighlightLayer, 'CategoryHighlightLayer', AnnotationLayer.$);
    CategoryHighlightLayer.nf = DependencyProperty.i("BAndHighlightWidth", Number_$type, CategoryHighlightLayer.$, new PropertyMetadata(2, 10, function (a, b) { return a.raisePropertyChanged("BAndHighlightWidth", b.oldValue, b.newValue); }));
    return CategoryHighlightLayer;
}(AnnotationLayer));
export { CategoryHighlightLayer };
Type.dep(DependencyProperty, PropertyMetadata, CategoryHighlightLayer, 'raisePropertyChanged', ['TargetAxis:m4:ng', [CategoryAxisBase.$, null], 'UseInterpolation:m7:nh', [0, false]]);
/**
 * @hidden
 */
var CategoryHighlightLayerView = /** @class */ (function (_super) {
    tslib_1.__extends(CategoryHighlightLayerView, _super);
    function CategoryHighlightLayerView(a) {
        var _this = _super.call(this, a) || this;
        _this.b1 = null;
        _this.b2 = null;
        _this.b3 = null;
        _this.b1 = a;
        _this.b3 = new List$1(Rectangle.$, 0);
        return _this;
    }
    CategoryHighlightLayerView.prototype.ap = function () {
        var _this = this;
        _super.prototype.ap.call(this);
        this.b2 = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.ca);
            $ret.activate = runOn(_this, _this.b5);
            $ret.disactivate = runOn(_this, _this.b7);
            $ret.destroy = runOn(_this, _this.b6);
            return $ret;
        })());
    };
    CategoryHighlightLayerView.prototype.ca = function () {
        var a = new Rectangle();
        a.ab = false;
        this.b3.add(a);
        return a;
    };
    CategoryHighlightLayerView.prototype.b5 = function (a) {
        a._visibility = 0;
    };
    CategoryHighlightLayerView.prototype.b7 = function (a) {
        a._visibility = 1;
    };
    CategoryHighlightLayerView.prototype.b6 = function (a) {
        this.b3.remove(a);
    };
    CategoryHighlightLayerView.prototype.b8 = function (a) {
        if (a == null) {
            return a;
        }
        return BrushUtil.h(a, 0.1);
    };
    CategoryHighlightLayerView.prototype.b9 = function (a) {
        if (a != null) {
            var b = BrushUtil.h(a, 0.3);
            if (b.isGradient) {
                var c = b;
                if (c.gradientStops != null) {
                    for (var d = 0; d < c.gradientStops.length; d++) {
                        var e = c.gradientStops[d];
                        e.color = Color.u(truncate(Math.round((e.color.l) * 0.2)), e.color.o, e.color.n, e.color.m);
                        e.color = e.color;
                    }
                }
            }
            else {
                b.color = Color.u(truncate(Math.round((b.color.l) * 0.2)), b.color.o, b.color.n, b.color.m);
                b.color = b.color;
            }
            return b;
        }
        else {
            return null;
        }
    };
    CategoryHighlightLayerView.prototype.b4 = function (a, b, c, d, e) {
        a._visibility = 0;
        a.n = b;
        a.o = c;
        a.width = d;
        a.height = e;
    };
    CategoryHighlightLayerView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d && !b) {
            for (var c = 0; c < this.b3.count; c++) {
                var d = this.b3._inner[c];
                if (d._visibility == 0) {
                    a.v(d);
                }
            }
        }
    };
    CategoryHighlightLayerView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        for (var b = 0; b < this.b3.count; b++) {
            this.e.a2.exportRectangleData(a, this.b3._inner[b], "cihRect", ["Main", "CategoryItem"]);
        }
    };
    CategoryHighlightLayerView.$t = markType(CategoryHighlightLayerView, 'CategoryHighlightLayerView', AnnotationLayerView.$);
    return CategoryHighlightLayerView;
}(AnnotationLayerView));
export { CategoryHighlightLayerView };
